#[non_exhaustive]pub enum ParserError {
Decode(DecodeError),
UnsupportedVersion {
layer_name: String,
version: u32,
},
InvalidTags,
InvalidGeometry,
CoordinateOverflow {
value: i32,
},
}Expand description
An error that can occur during parsing of a vector tile.
Examples
use mvt_reader::error::ParserError;
fn example() -> Result<(), ParserError> {
Err(ParserError::InvalidTags)
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Decode(DecodeError)
A protobuf decoding failure.
UnsupportedVersion
The layer has an unsupported vector tile version.
InvalidTags
The tags section of a feature is malformed.
InvalidGeometry
The geometry section of a feature is malformed.
CoordinateOverflow
A coordinate value does not fit in the requested numeric type.