Struct mvt_reader::error::DecodeError
source · pub struct DecodeError { /* private fields */ }Expand description
An error indicating a decoding failure during the parsing of a vector tile.
Implementations
sourceimpl DecodeError
impl DecodeError
sourcepub fn new(source: DecodeError) -> Self
pub fn new(source: DecodeError) -> Self
Creates a new DecodeError instance with the provided decoding error source from prost.
Arguments
- source - The underlying decoding error source from prost.