pub struct VersionError { /* private fields */ }Expand description
A structure representing a version error in a vector tile.
Implementations
Sourceimpl VersionError
impl VersionError
Sourcepub fn new(layer_name: String, version: u32) -> Self
pub fn new(layer_name: String, version: u32) -> Self
Creates a new VersionError instance with the provided layer name and version.
Arguments
layer_name- The name of the layer.version- The unsupported version number.
Examples
use mvt_reader::error::VersionError;
let layer_name = String::from("my_layer");
let version = 3;
let version_error = VersionError::new(layer_name, version);Trait Implementations
Sourceimpl Debug for VersionError
impl Debug for VersionError
Sourceimpl Display for VersionError
impl Display for VersionError
Sourcefn fmt(&self, f: &mut Formatter<'_>) -> Result
fn fmt(&self, f: &mut Formatter<'_>) -> Result
Formats the error message associated with the VersionError.
Arguments
f- The formatter to write the output to.
Examples
use mvt_reader::error::VersionError;
let layer_name = String::from("my_layer");
let version = 3;
let version_error = VersionError::new(layer_name, version);
println!("{}", version_error);Sourceimpl Error for VersionError
impl Error for VersionError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()