This module provide the Layer struct.
The Layer struct represents a layer in a vector tile, containing metadata about the layer and its features.
Types
The layer module defines the following types:
Layer: Represents a layer in a vector tile, containing metadata about the layer and its features.
Structs
- Layer
- A structure representing a layer in a vector tile.