pub struct Layer {
pub layer_index: usize,
pub version: u32,
pub name: String,
pub feature_count: usize,
pub extent: u32,
}Expand description
A structure representing a layer in a vector tile.
Fields
layer_index: usizeThe index of the layer in the vector tile.
version: u32The version of the layer.
name: StringThe name of the layer.
feature_count: usizeThe number of features in the layer.
extent: u32The extent of the layer, representing the size of the tile in pixels. Defaults to 4096.