This module provides error types for the mvt-reader crate.
The ParserError enum represents all possible errors that can occur during
parsing of a vector tile.
Enums
- Parser
Error - An error that can occur during parsing of a vector tile.