This module provides types and utilities for working with features in the mvt-reader crate.
A feature represents a geographic entity with geometry and associated properties. Features are typically found within layers of a vector tile.
Types
The feature module defines the following types:
Feature: Represents a feature with geometry, an optional id and optional properties.
Structs
- Feature
- A structure representing a feature in a vector tile.
Enums
- Value
- An enumeration representing the value of a property associated with a feature.